import { useCallback } from "react";
import useHttpRequest from "./useHttpRequest";
import { get } from "../utils/axios";

const cdn = process.env.REACT_APP_CDN_URL;

const defaultResourcesInput = {
  page: 1,
  pageSize: 10,
  sortBy: null,
  sortDirection: 0,
  fullTextSearch: null,
  resourceCode: null,
  resourceName: null,
  categoryId: null,
  secured: null
};

const getResourcesEndpoint = (filters) => {
  const {
    page,
    pageSize,
    sortBy,
    sortDirection,
    fullTextSearch,
    resourceCode,
    resourceName,
    categoryId,
    secured
  } = filters;
  let endpoint = `${cdn}/admin/resources?Page=${page}&PageSize=${pageSize}&SortDirection=${sortDirection}`;
  if (sortBy) endpoint += `&SortBy=${sortBy}`;
  if (fullTextSearch) endpoint += `&FullTextSearch=${fullTextSearch}`;
  if (resourceCode) endpoint += `&ResourceCode=${resourceCode}`;
  if (resourceCode) endpoint += `&ResourceName=${resourceName}`;
  if (categoryId) endpoint += `&CategoryId=${categoryId}`;
  if (secured) endpoint += `&Secured=${secured}`;
  return endpoint;
};

const useResourcesApi = () => {
  const { exec } = useHttpRequest();

  const getResources = useCallback(
    (filters, options) => {
      const input = { ...defaultResourcesInput, ...filters };
      const endpoint = getResourcesEndpoint(input);
      const promise = exec(() => get(endpoint), options);
      return promise;
    },
    [exec]
  );

  return {
    getResources
  };
};

export default useResourcesApi;
