import React, { useState, useEffect, useMemo } from "react";
import { Grid, CircularProgress, Checkbox } from "@material-ui/core";
import MUIDataTable from "mui-datatables";
import PageTitle from "../../../components/PageTitle";
import { useResourcesApi } from "../../../api";

const ResourcesContainer = () => {
  const [list, setList] = useState({ loaded: false });
  const { getResources } = useResourcesApi();

  useEffect(() => {
    getResources(
      {},
      {
        onCompleted: (resources) => {
          const data = Object.assign(resources, { loaded: true });
          setList(data);
        }
      }
    );
  }, [getResources]);

  const columns = useMemo(
    () => [
      {
        label: "Code",
        name: "resourceCode",
        options: {
          display: true,
          draggable: true,
          download: false,
          print: false,
          searchable: true,
          sort: true,
          filter: true,
          filterType: "textField",
          filterList: undefined,
          hint: undefined
        }
      },
      {
        label: "Name",
        name: "resourceName",
        options: {
          display: true,
          draggable: true,
          download: false,
          print: false,
          searchable: true,
          sort: true,
          filter: true,
          filterType: "textField",
          filterList: undefined,
          hint: undefined
        }
      },
      {
        label: "Category",
        name: "categoryId",
        options: {
          display: true,
          draggable: true,
          download: false,
          print: false,
          searchable: true,
          sort: true,
          filter: true,
          filterType: "dropdown",
          filterList: [],
          hint: undefined
        }
      },
      {
        label: "Secured",
        name: "secured",
        options: {
          display: true,
          draggable: true,
          download: false,
          print: false,
          searchable: true,
          sort: true,
          filter: true,
          filterType: "checkbox",
          filterList: undefined,
          hint: undefined,
          customBodyRender: (value, tableMeta, updateValue) => {
            return (
              <Checkbox
                disabled
                size="small"
                checked={value}
                style={{ padding: "0" }}
              />
            );
          }
        }
      }
    ],
    []
  );

  return (
    <>
      <PageTitle title="ResourcesX" />
      {list.loaded === false ? (
        <CircularProgress size={26} />
      ) : (
        <Grid container spacing={4}>
          <Grid item xs={12}>
            <MUIDataTable
              title="Resources"
              columns={columns}
              data={list.values ?? []}
              options={{
                filterType: "textField",
                expandableRows: false,
                print: false,
                selectableRows: false,
                rowsPerPage: 10,
                rowsPerPageOptions: [10, 20, 50, 100]
              }}
            />
          </Grid>
        </Grid>
      )}
    </>
  );
};

export default ResourcesContainer;
